/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal :
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/

package org.esupportail.portal.channels.CPref.actions;   

import java.util.Hashtable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.esupportail.portal.channels.CPref.CPref;
import org.esupportail.portal.channels.CPref.UpdateAction;
import org.esupportail.portal.channels.CPref.LDAP.Exceptions.LDAPException;
import org.esupportail.portal.channels.CPref.config.Config;
import org.esupportail.portal.channels.CPref.config.LdapAttribut;
import org.esupportail.portal.channels.CPref.formats.Format;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.channels.plugins.Message;
import org.esupportail.portal.utils.channels.plugins.MessageBean;
import org.jasig.portal.PortalException;
import org.jasig.portal.security.IPerson;

public class Redirection extends UpdateAction{  
 
    private static final Log log = LogFactory.getLog(CPref.class);
    private String login;
    private Format format;

	/**
	 * @param mainChannel
	 */
	public Redirection(MainChannel mainChannel) {
		super(mainChannel);   
	}
	
	/** 
	 * Positionnement des actions relatives  cette classe
	 */
	public boolean prepare() throws FrameWorkException {
		setActionVisu("visuMessagerie");
		setActionModif("messagerie");
		setActionValid("validMessagerie");
		
		/*
		 * Recherche du login de la persone connecte
		 */
		login = (String)mainChannel.getStaticData().getPerson().getAttribute(IPerson.USERNAME);
		
		/* 
		 * Recherche le format pour rechercher l'adresse par dfaut de 
		 * redirection
		 */
		calculFormat();
		
		/*
		 * Calcul de l'adresse de redirection
		 */
		Hashtable ht = new Hashtable();
		ht.put("mailRef", format.transform(null).replaceFirst("%login%",login));
		setXSLParameter(ht);
		addDefaultXslParameters();
		return true;
	}

	/** 
	 * Postionnement des champs en lecture
	 */
	public String[] prepareListFieldRead() throws FrameWorkException {
		String[] readFields = new String[1];
		readFields[0] = "mail";
		return readFields;
	}

	/** 
	 * Postionnement des champs en criture
	 */
	public String[] prepareListFieldWrite() throws FrameWorkException {
		String[] modifyFields = new String[1];
		modifyFields[0] = "n2atrmaildrop";
		return modifyFields;
	}	 
	
	/**
	 * Mthode permettant d'enregistrer les donnes
	 * @return Boolean : 
	 * 	* Boolean.TRUE: validation effectue avec succs
	 * 	* Boolean.FALSE: redirection sur le plugin message
	 */
	public Boolean validation() { 
		
		/*Ouverture de la connextion LDAP*/ 
		this.openLDAP(true);   
		
		/*Positionnement des valeurs  enregistrer*/
		String[] attribsValue = new String[2];	
		for (int i=0; i<getModifiedFileds().length;i++){
			String paramName = getModifiedFileds()[i];
			if (runtimeData.getParameter(paramName)!=null){
				attribsValue[i] = runtimeData.getParameter(paramName).replaceFirst("%login%",login);
			}
			else{
				attribsValue[i] = format.transform(null).replaceFirst("%login%",login);
			}
		}  
		LDAPconnexion.setAttributesValues(attribsValue);
		
		LDAPconnexion.setAttributes(getModifiedFileds());
		
		/*criture*/
		try {
			LDAPconnexion.write(dn);
		} catch (LDAPException e) {
			try {
				Message.message(mainChannel,runtimeData,new MessageBean(e.getDisplayMessage()),"default",new Hashtable());
			} catch (PortalException e1) {
			    log.error("Redirection::validation():PortalException : ",e1);
			}
			return Boolean.FALSE;
		}
		
		/*Fermeture de la connextion LDAP*/ 
		this.closeLDAP();
		
		return Boolean.TRUE;
	}
	
	
	public void calculFormat(){
		
		if (format==null){
		
			LdapAttribut attrib = (LdapAttribut)Config.getInstance().getAttribLdap("n2atrmaildrop");
			String group = (String)mainChannel.getStaticData().get("plug.esup.restrictedAction");
			
			Class c;
			
			try {
				if (attrib.getFormat(group)!=null){
					c = Class.forName(attrib.getFormat(group));
					format = (Format)c.newInstance();
				}
				
			} catch (ClassNotFoundException e) {
			    log.error("Redirection::calculFormat():ClassNotFoundException : "+attrib.getFormat(group));
			} catch (InstantiationException e) {
			    log.error("Redirection::calculFormat():InstantiationException : "+attrib.getFormat(group));
			} catch (IllegalAccessException e) { 
			    log.error("Redirection::calculFormat():IllegalAccessException : "+attrib.getFormat(group));
			}	
		}
	}

}
	
